"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const application_1 = require("@jupyterlab/application");
const apputils_1 = require("@jupyterlab/apputils");
const coreutils_1 = require("@jupyterlab/coreutils");
const docmanager_1 = require("@jupyterlab/docmanager");
const widgets_1 = require("@lumino/widgets");
const requests_helper_1 = require("requests-helper");
require("../style/index.css");
// tslint:disable: variable-name
let unique = 0;
const extension = {
    activate,
    autoStart: true,
    id: "jupyterlab_iframe",
    requires: [docmanager_1.IDocumentManager, apputils_1.ICommandPalette, application_1.ILayoutRestorer],
};
class IFrameWidget extends widgets_1.Widget {
    constructor(path) {
        super();
        this.id = path + "-" + unique;
        unique += 1;
        this.title.label = path;
        this.title.closable = true;
        if (!path.startsWith("http")) {
            // use https, its 2019
            path = "https://" + path;
        }
        const div = document.createElement("div");
        div.classList.add("iframe-widget");
        const iframe = document.createElement("iframe");
        // TODO proxy path if necessary
        requests_helper_1.request("get", path).then((res) => {
            if (res.ok && res.headers.indexOf("Access-Control-Allow-Origin") < 0) {
                // tslint:disable-next-line: no-console
                console.log("site accesible: proceeding");
                iframe.src = path;
            }
            else {
                // tslint:disable-next-line: no-console
                console.log("site failed with code " + res.status.toString());
                // tslint:disable-next-line: no-empty
                if (res.status === 404) {
                }
                else if (res.status === 401) {
                    // tslint:disable-next-line: no-empty
                }
                else {
                    // tslint:disable-next-line: no-console
                    path = "iframes/proxy?path=" + encodeURI(path);
                    iframe.src = coreutils_1.PageConfig.getBaseUrl() + path;
                    // tslint:disable-next-line: no-console
                    console.log("setting proxy for " + path);
                }
            }
        });
        div.appendChild(iframe);
        this.node.appendChild(div);
    }
}
// tslint:disable-next-line: max-classes-per-file
class OpenIFrameWidget extends widgets_1.Widget {
    constructor() {
        const body = document.createElement("div");
        const existingLabel = document.createElement("label");
        existingLabel.textContent = "Site:";
        const input = document.createElement("input");
        input.value = "";
        input.placeholder = "http://path.to.site";
        body.appendChild(existingLabel);
        body.appendChild(input);
        super({ node: body });
    }
    getValue() {
        return this.inputNode.value;
    }
    get inputNode() {
        return this.node.getElementsByTagName("input")[0];
    }
}
function registerSite(app, palette, site) {
    const command = "iframe:open-" + site;
    app.commands.addCommand(command, {
        execute: () => {
            const widget = new IFrameWidget(site);
            app.shell.add(widget);
            app.shell.activateById(widget.id);
        },
        isEnabled: () => true,
        label: "Open " + site,
    });
    palette.addItem({ command, category: "Sites" });
}
// tslint:disable-next-line: max-line-length
function activate(app, docManager, palette, restorer) {
    // Declare a widget variable
    let widget;
    // Add an application command
    const open_command = "iframe:open";
    app.commands.addCommand(open_command, {
        execute: (args) => {
            let path = typeof args.path === "undefined" ? "" : args.path;
            if (path === "") {
                apputils_1.showDialog({
                    body: new OpenIFrameWidget(),
                    buttons: [apputils_1.Dialog.cancelButton(), apputils_1.Dialog.okButton({ label: "GO" })],
                    focusNodeSelector: "input",
                    title: "Open site",
                }).then((result) => {
                    if (result.button.label === "Cancel") {
                        return;
                    }
                    if (!result.value) {
                        return null;
                    }
                    path = result.value;
                    widget = new IFrameWidget(path);
                    app.shell.add(widget);
                    app.shell.activateById(widget.id);
                });
            }
            else {
                widget = new IFrameWidget(path);
                app.shell.add(widget);
                app.shell.activateById(widget.id);
            }
        },
        isEnabled: () => true,
        label: "Open IFrame",
    });
    // Add the command to the palette.
    palette.addItem({ command: open_command, category: "Sites" });
    // grab sites from serverextension
    requests_helper_1.request("get", coreutils_1.PageConfig.getBaseUrl() + "iframes/").then((res) => {
        if (res.ok) {
            const jsn = res.json();
            const welcome = jsn.welcome;
            let welcome_included = false;
            const sites = jsn.sites;
            for (const site of sites) {
                // tslint:disable-next-line: no-console
                console.log("adding quicklink for " + site);
                if (site === welcome) {
                    welcome_included = true;
                }
                if (site) {
                    registerSite(app, palette, site);
                }
            }
            if (!welcome_included) {
                if (welcome !== "") {
                    registerSite(app, palette, welcome);
                }
            }
            if (welcome) {
                app.restored.then(() => {
                    if (!localStorage.getItem("jupyterlab_iframe_welcome")) {
                        localStorage.setItem("jupyterlab_iframe_welcome", "false");
                        app.commands.execute("iframe:open-" + welcome);
                    }
                });
            }
        }
    });
    // tslint:disable-next-line: no-console
    console.log("JupyterLab extension jupyterlab_iframe is activated!");
}
exports._activate = activate;
exports.default = extension;
